@@ -10,7 +10,7 @@ require HTML::DOM::Element;
 require HTML::DOM::NodeList::Magic;
 #require HTML::DOM::Collection::Elements;
 
-our $VERSION = '0.045';
+our $VERSION = '0.046';
 our @ISA = qw'HTML::DOM::Element';
 
 use overload fallback => 1,
@@ -407,7 +407,7 @@ package HTML::DOM::NodeList::Radio; # solely for HTML::Form compatibility
 use Carp 'croak';
 require HTML::DOM::NodeList;
 
-our $VERSION = '0.045';
+our $VERSION = '0.046';
 our @ISA = qw'HTML::DOM::NodeList';
 
 sub type { 'radio' }
@@ -479,7 +479,7 @@ use warnings;
 
 use Scalar::Util 'weaken';
 
-our $VERSION = '0.045';
+our $VERSION = '0.046';
 
 require HTML::DOM::Collection;
 our @ISA = 'HTML::DOM::Collection';
@@ -656,7 +656,7 @@ L<HTML::Form>
 # ------- HTMLSelectElement interface ---------- #
 
 package HTML::DOM::Element::Select;
-our $VERSION = '0.045';
+our $VERSION = '0.046';
 our @ISA = 'HTML::DOM::Element';
 
 use overload fallback=>1, '@{}' => sub { shift->options };
@@ -749,12 +749,13 @@ package HTML::DOM::Collection::Options;
 use strict;
 use warnings;
 
-our $VERSION = '0.045';
+our $VERSION = '0.046';
 
 use Carp 'croak';
 use constant sel => 5; # must not conflict with super
 { no strict 'refs'; delete ${__PACKAGE__."::"}{sel} } # after compilation
 
+require HTML::DOM::Exception;
 require HTML::DOM::Collection;
 our @ISA = qw'HTML::DOM::Collection';
 
@@ -826,7 +827,7 @@ sub length { # override
 # ------- HTMLOptGroupElement interface ---------- #
 
 package HTML::DOM::Element::OptGroup;
-our $VERSION = '0.045';
+our $VERSION = '0.046';
 our @ISA = 'HTML::DOM::Element';
 
 sub label  { shift->_attr( label => @_) }
@@ -836,10 +837,11 @@ sub label  { shift->_attr( label => @_) }
 # ------- HTMLOptionElement interface ---------- #
 
 package HTML::DOM::Element::Option;
-our $VERSION = '0.045';
+our $VERSION = '0.046';
 our @ISA = qw'HTML::DOM::Element';
 
 use Carp 'croak';
+require HTML::DOM::Exception;
 
 *form = \&HTML::DOM::Element::Select::form;
 sub defaultSelected   {
@@ -948,7 +950,7 @@ sub _reset { delete shift->{_HTML_DOM_sel} }
 # ------- HTMLInputElement interface ---------- #
 
 package HTML::DOM::Element::Input;
-our $VERSION = '0.045';
+our $VERSION = '0.046';
 our @ISA = qw'HTML::DOM::Element';
 
 use Carp 'croak';
@@ -971,7 +973,18 @@ sub checked        {
 	else {
 		$ret = $self->{_HTML_DOM_checked}
 	}
-	@_ and $self->{_HTML_DOM_checked} = shift;
+	if(  @_ && !$ret != not $self->{_HTML_DOM_checked} = shift
+	 and !$ret and $self->type eq 'radio'  ) {
+		if(
+		 my $form = $self->form and defined(my $name = $self->name)
+		) {
+			no warnings 'uninitialized';
+			$_ != $self && $_->type eq 'radio'
+			 && $_->name eq $name
+			  and $_->{_HTML_DOM_checked} = 0
+				for $form->elements;
+		}
+	}
 	return $ret;
 }
 *disabled = \&HTML::DOM::Element::Select::disabled;
@@ -1159,7 +1172,7 @@ sub content {
 # ------- HTMLTextAreaElement interface ---------- #
 
 package HTML::DOM::Element::TextArea;
-our $VERSION = '0.045';
+our $VERSION = '0.046';
 our @ISA = qw'HTML::DOM::Element';
 
 sub defaultValue { # same as HTML::DOM::Element::Title::text
@@ -1207,7 +1220,7 @@ sub _reset {
 # ------- HTMLButtonElement interface ---------- #
 
 package HTML::DOM::Element::Button;
-our $VERSION = '0.045';
+our $VERSION = '0.046';
 our @ISA = qw'HTML::DOM::Element';
 
 *form = \&HTML::DOM::Element::Select::form;
@@ -1222,7 +1235,7 @@ sub value      { shift->attr( value       => @_) }
 # ------- HTMLLabelElement interface ---------- #
 
 package HTML::DOM::Element::Label;
-our $VERSION = '0.045';
+our $VERSION = '0.046';
 our @ISA = qw'HTML::DOM::Element';
 
 *form = \&HTML::DOM::Element::Select::form;
@@ -1232,7 +1245,7 @@ sub htmlFor { shift->_attr( for       => @_) }
 # ------- HTMLFieldSetElement interface ---------- #
 
 package HTML::DOM::Element::FieldSet;
-our $VERSION = '0.045';
+our $VERSION = '0.046';
 our @ISA = qw'HTML::DOM::Element';
 
 *form = \&HTML::DOM::Element::Select::form;
@@ -1240,7 +1253,7 @@ our @ISA = qw'HTML::DOM::Element';
 # ------- HTMLLegendElement interface ---------- #
 
 package HTML::DOM::Element::Legend;
-our $VERSION = '0.045';
+our $VERSION = '0.046';
 our @ISA = qw'HTML::DOM::Element';
 
 *form = \&HTML::DOM::Element::Select::form;
